dhcpkit.ipv6.message_handlers.standard module
=============================================

.. automodule:: dhcpkit.ipv6.message_handlers.standard
    :members:
    :undoc-members:
    :show-inheritance:
